@@ -17,12 +17,11 @@
 # Licensed to PSF under a Contributor Agreement.
 #
 
-from __future__ import absolute_import
 
 import sys
 from . import context
 
-VERSION = (3, 6, 3, 0)
+VERSION = (4, 0, 0)
 __version__ = '.'.join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
